StorageInfo class

Information about the storage capacity and usage.

Constructors

StorageInfo({required int totalStorage, required int freeStorage, required int usedStorage, required double usagePercentage})
const
StorageInfo.fromMap(Map map)
Creates a StorageInfo from a map.
factory

Properties

freeStorage int
Available storage space on the device in bytes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalStorage int
Total storage space on the device in bytes.
final
usagePercentage double
Usage percentage, between 0.0 and 100.0.
final
usedStorage int
Used storage space on the device in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this object to a map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited