MethodChannelAdvancedDeviceInfo class
An implementation of AdvancedDeviceInfoPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- AdvancedDeviceInfoPlatform
- MethodChannelAdvancedDeviceInfo
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCpuInfo(
) → Future< CpuInfo> -
override
-
getDeviceInfo(
) → Future< DeviceInfo> -
override
-
getMemoryInfo(
) → Future< MemoryInfo> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
getScreenInfo(
) → Future< ScreenInfo> -
override
-
getStorageInfo(
) → Future< StorageInfo> -
override
-
getSystemInfo(
) → Future< SystemInfo> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited