AdvancedDeviceInfoPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- AdvancedDeviceInfoPlatform
- Implementers
Constructors
- AdvancedDeviceInfoPlatform()
- Constructs a AdvancedDeviceInfoPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCpuInfo(
) → Future< CpuInfo> -
getDeviceInfo(
) → Future< DeviceInfo> -
getMemoryInfo(
) → Future< MemoryInfo> -
getPlatformVersion(
) → Future< String?> -
getScreenInfo(
) → Future< ScreenInfo> -
getStorageInfo(
) → Future< StorageInfo> -
getSystemInfo(
) → Future< SystemInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AdvancedDeviceInfoPlatform
-
The default instance of AdvancedDeviceInfoPlatform to use.
getter/setter pair