SystemInfo class
Aggregated system-wide information.
Constructors
- SystemInfo({required DeviceInfo deviceInfo, required StorageInfo storageInfo, required MemoryInfo memoryInfo, required CpuInfo cpuInfo, required ScreenInfo screenInfo})
-
const
- SystemInfo.fromMap(Map map)
-
Creates a SystemInfo from a nested map.
factory
Properties
- cpuInfo → CpuInfo
-
Processor capabilities.
final
- deviceInfo → DeviceInfo
-
General device metadata.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- memoryInfo → MemoryInfo
-
Physical memory (RAM) capacity and usage details.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenInfo → ScreenInfo
-
Display characteristics.
final
- storageInfo → StorageInfo
-
Storage capacity and usage details.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this object to a map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited